# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_token_lifetime_minutes": "accessTokenLifetimeMinutes",
    "accessibility_error_redirect_url": "accessibilityErrorRedirectUrl",
    "accessibility_login_redirect_url": "accessibilityLoginRedirectUrl",
    "accessibility_self_service": "accessibilitySelfService",
    "account_link_action": "accountLinkAction",
    "account_link_group_includes": "accountLinkGroupIncludes",
    "acs_binding": "acsBinding",
    "acs_type": "acsType",
    "admin_roles": "adminRoles",
    "always_include_in_token": "alwaysIncludeInToken",
    "app_excludes": "appExcludes",
    "app_id": "appId",
    "app_includes": "appIncludes",
    "app_settings_json": "appSettingsJson",
    "array_enums": "arrayEnums",
    "array_one_ofs": "arrayOneOfs",
    "array_type": "arrayType",
    "assertion_signed": "assertionSigned",
    "attribute_statements": "attributeStatements",
    "auth_provider": "authProvider",
    "auth_server_id": "authServerId",
    "auth_url": "authUrl",
    "authn_context_class_ref": "authnContextClassRef",
    "authorization_binding": "authorizationBinding",
    "authorization_url": "authorizationUrl",
    "auto_key_rotation": "autoKeyRotation",
    "auto_submit_toolbar": "autoSubmitToolbar",
    "button_field": "buttonField",
    "button_selector": "buttonSelector",
    "claim_type": "claimType",
    "client_basic_secret": "clientBasicSecret",
    "client_id": "clientId",
    "client_secret": "clientSecret",
    "client_uri": "clientUri",
    "client_whitelists": "clientWhitelists",
    "consent_method": "consentMethod",
    "consent_type": "consentType",
    "cost_center": "costCenter",
    "country_code": "countryCode",
    "credentials_last_rotated": "credentialsLastRotated",
    "credentials_next_rotation": "credentialsNextRotation",
    "credentials_rotation_mode": "credentialsRotationMode",
    "credentials_scheme": "credentialsScheme",
    "custom_client_id": "customClientId",
    "custom_profile_attributes": "customProfileAttributes",
    "default_language": "defaultLanguage",
    "default_relay_state": "defaultRelayState",
    "delete_when_absent": "deleteWhenAbsent",
    "deprovisioned_action": "deprovisionedAction",
    "digest_algorithm": "digestAlgorithm",
    "display_name": "displayName",
    "dynamic_locations": "dynamicLocations",
    "email_recovery": "emailRecovery",
    "employee_number": "employeeNumber",
    "entity_key": "entityKey",
    "entity_url": "entityUrl",
    "expires_at": "expiresAt",
    "expression_type": "expressionType",
    "expression_value": "expressionValue",
    "external_name": "externalName",
    "extra_field_selector": "extraFieldSelector",
    "extra_field_value": "extraFieldValue",
    "fido_u2f": "fidoU2f",
    "fido_webauthn": "fidoWebauthn",
    "first_name": "firstName",
    "google_otp": "googleOtp",
    "grant_type_whitelists": "grantTypeWhitelists",
    "grant_types": "grantTypes",
    "group_assignments": "groupAssignments",
    "group_blacklists": "groupBlacklists",
    "group_filter_type": "groupFilterType",
    "group_id": "groupId",
    "group_memberships": "groupMemberships",
    "group_whitelists": "groupWhitelists",
    "groups_action": "groupsAction",
    "groups_assignments": "groupsAssignments",
    "groups_attribute": "groupsAttribute",
    "groups_filters": "groupsFilters",
    "groups_includeds": "groupsIncludeds",
    "hide_ios": "hideIos",
    "hide_web": "hideWeb",
    "honor_force_authn": "honorForceAuthn",
    "honorific_prefix": "honorificPrefix",
    "honorific_suffix": "honorificSuffix",
    "http_post_binding": "httpPostBinding",
    "http_redirect_binding": "httpRedirectBinding",
    "idp_id": "idpId",
    "idp_issuer": "idpIssuer",
    "idp_type": "idpType",
    "inline_hook_id": "inlineHookId",
    "issuer_mode": "issuerMode",
    "issuer_url": "issuerUrl",
    "jwks_binding": "jwksBinding",
    "jwks_url": "jwksUrl",
    "key_id": "keyId",
    "key_name": "keyName",
    "key_years_valid": "keyYearsValid",
    "last_name": "lastName",
    "login_uri": "loginUri",
    "logo_uri": "logoUri",
    "manager_id": "managerId",
    "match_attribute": "matchAttribute",
    "match_type": "matchType",
    "max_clock_skew": "maxClockSkew",
    "max_length": "maxLength",
    "metadata_publish": "metadataPublish",
    "mfa_lifetime": "mfaLifetime",
    "mfa_prompt": "mfaPrompt",
    "mfa_remember_device": "mfaRememberDevice",
    "mfa_required": "mfaRequired",
    "middle_name": "middleName",
    "min_length": "minLength",
    "mobile_phone": "mobilePhone",
    "name_format": "nameFormat",
    "network_connection": "networkConnection",
    "network_excludes": "networkExcludes",
    "network_includes": "networkIncludes",
    "nick_name": "nickName",
    "okta_call": "oktaCall",
    "okta_otp": "oktaOtp",
    "okta_password": "oktaPassword",
    "okta_push": "oktaPush",
    "okta_question": "oktaQuestion",
    "okta_sms": "oktaSms",
    "omit_secret": "omitSecret",
    "one_ofs": "oneOfs",
    "optional_field1": "optionalField1",
    "optional_field1_value": "optionalField1Value",
    "optional_field2": "optionalField2",
    "optional_field2_value": "optionalField2Value",
    "optional_field3": "optionalField3",
    "optional_field3_value": "optionalField3Value",
    "password_auto_unlock_minutes": "passwordAutoUnlockMinutes",
    "password_change": "passwordChange",
    "password_dictionary_lookup": "passwordDictionaryLookup",
    "password_exclude_first_name": "passwordExcludeFirstName",
    "password_exclude_last_name": "passwordExcludeLastName",
    "password_exclude_username": "passwordExcludeUsername",
    "password_expire_warn_days": "passwordExpireWarnDays",
    "password_field": "passwordField",
    "password_history_count": "passwordHistoryCount",
    "password_max_age_days": "passwordMaxAgeDays",
    "password_max_lockout_attempts": "passwordMaxLockoutAttempts",
    "password_min_age_minutes": "passwordMinAgeMinutes",
    "password_min_length": "passwordMinLength",
    "password_min_lowercase": "passwordMinLowercase",
    "password_min_number": "passwordMinNumber",
    "password_min_symbol": "passwordMinSymbol",
    "password_min_uppercase": "passwordMinUppercase",
    "password_reset": "passwordReset",
    "password_selector": "passwordSelector",
    "password_show_lockout_failures": "passwordShowLockoutFailures",
    "password_unlock": "passwordUnlock",
    "platform_includes": "platformIncludes",
    "policy_id": "policyId",
    "policy_uri": "policyUri",
    "post_logout_redirect_uris": "postLogoutRedirectUris",
    "postal_address": "postalAddress",
    "preconfigured_app": "preconfiguredApp",
    "preferred_language": "preferredLanguage",
    "primary_phone": "primaryPhone",
    "profile_master": "profileMaster",
    "profile_url": "profileUrl",
    "protocol_type": "protocolType",
    "provider_id": "providerId",
    "provisioning_action": "provisioningAction",
    "question_min_length": "questionMinLength",
    "question_recovery": "questionRecovery",
    "raw_status": "rawStatus",
    "recovery_answer": "recoveryAnswer",
    "recovery_email_token": "recoveryEmailToken",
    "recovery_question": "recoveryQuestion",
    "redirect_uris": "redirectUris",
    "refresh_token_lifetime_minutes": "refreshTokenLifetimeMinutes",
    "refresh_token_window_minutes": "refreshTokenWindowMinutes",
    "request_compressed": "requestCompressed",
    "request_integration": "requestIntegration",
    "request_signature_algorithm": "requestSignatureAlgorithm",
    "request_signature_scope": "requestSignatureScope",
    "response_signature_algorithm": "responseSignatureAlgorithm",
    "response_signature_scope": "responseSignatureScope",
    "response_signed": "responseSigned",
    "response_types": "responseTypes",
    "reveal_password": "revealPassword",
    "rsa_token": "rsaToken",
    "scope_whitelists": "scopeWhitelists",
    "second_email": "secondEmail",
    "session_idle": "sessionIdle",
    "session_lifetime": "sessionLifetime",
    "session_persistent": "sessionPersistent",
    "shared_password": "sharedPassword",
    "shared_username": "sharedUsername",
    "sign_on_mode": "signOnMode",
    "sign_on_redirect_url": "signOnRedirectUrl",
    "sign_on_url": "signOnUrl",
    "signature_algorithm": "signatureAlgorithm",
    "skip_unlock": "skipUnlock",
    "sms_recovery": "smsRecovery",
    "source_id": "sourceId",
    "source_name": "sourceName",
    "source_type": "sourceType",
    "sp_issuer": "spIssuer",
    "sso_binding": "ssoBinding",
    "sso_destination": "ssoDestination",
    "sso_url": "ssoUrl",
    "street_address": "streetAddress",
    "subject_filter": "subjectFilter",
    "subject_formats": "subjectFormats",
    "subject_match_attribute": "subjectMatchAttribute",
    "subject_match_type": "subjectMatchType",
    "subject_name_id_format": "subjectNameIdFormat",
    "subject_name_id_template": "subjectNameIdTemplate",
    "suspended_action": "suspendedAction",
    "symantec_vip": "symantecVip",
    "target_id": "targetId",
    "target_name": "targetName",
    "target_type": "targetType",
    "token_binding": "tokenBinding",
    "token_endpoint_auth_method": "tokenEndpointAuthMethod",
    "token_url": "tokenUrl",
    "tos_uri": "tosUri",
    "url_regex": "urlRegex",
    "user_blacklists": "userBlacklists",
    "user_id": "userId",
    "user_identifier_attribute": "userIdentifierAttribute",
    "user_identifier_patterns": "userIdentifierPatterns",
    "user_identifier_type": "userIdentifierType",
    "user_info_binding": "userInfoBinding",
    "user_info_url": "userInfoUrl",
    "user_name_template": "userNameTemplate",
    "user_name_template_suffix": "userNameTemplateSuffix",
    "user_name_template_type": "userNameTemplateType",
    "user_type": "userType",
    "user_whitelists": "userWhitelists",
    "username_field": "usernameField",
    "username_selector": "usernameSelector",
    "username_template": "usernameTemplate",
    "users_excludeds": "usersExcludeds",
    "value_type": "valueType",
    "x5t_s256": "x5tS256",
    "yubikey_token": "yubikeyToken",
    "zip_code": "zipCode",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessTokenLifetimeMinutes": "access_token_lifetime_minutes",
    "accessibilityErrorRedirectUrl": "accessibility_error_redirect_url",
    "accessibilityLoginRedirectUrl": "accessibility_login_redirect_url",
    "accessibilitySelfService": "accessibility_self_service",
    "accountLinkAction": "account_link_action",
    "accountLinkGroupIncludes": "account_link_group_includes",
    "acsBinding": "acs_binding",
    "acsType": "acs_type",
    "adminRoles": "admin_roles",
    "alwaysIncludeInToken": "always_include_in_token",
    "appExcludes": "app_excludes",
    "appId": "app_id",
    "appIncludes": "app_includes",
    "appSettingsJson": "app_settings_json",
    "arrayEnums": "array_enums",
    "arrayOneOfs": "array_one_ofs",
    "arrayType": "array_type",
    "assertionSigned": "assertion_signed",
    "attributeStatements": "attribute_statements",
    "authProvider": "auth_provider",
    "authServerId": "auth_server_id",
    "authUrl": "auth_url",
    "authnContextClassRef": "authn_context_class_ref",
    "authorizationBinding": "authorization_binding",
    "authorizationUrl": "authorization_url",
    "autoKeyRotation": "auto_key_rotation",
    "autoSubmitToolbar": "auto_submit_toolbar",
    "buttonField": "button_field",
    "buttonSelector": "button_selector",
    "claimType": "claim_type",
    "clientBasicSecret": "client_basic_secret",
    "clientId": "client_id",
    "clientSecret": "client_secret",
    "clientUri": "client_uri",
    "clientWhitelists": "client_whitelists",
    "consentMethod": "consent_method",
    "consentType": "consent_type",
    "costCenter": "cost_center",
    "countryCode": "country_code",
    "credentialsLastRotated": "credentials_last_rotated",
    "credentialsNextRotation": "credentials_next_rotation",
    "credentialsRotationMode": "credentials_rotation_mode",
    "credentialsScheme": "credentials_scheme",
    "customClientId": "custom_client_id",
    "customProfileAttributes": "custom_profile_attributes",
    "defaultLanguage": "default_language",
    "defaultRelayState": "default_relay_state",
    "deleteWhenAbsent": "delete_when_absent",
    "deprovisionedAction": "deprovisioned_action",
    "digestAlgorithm": "digest_algorithm",
    "displayName": "display_name",
    "dynamicLocations": "dynamic_locations",
    "emailRecovery": "email_recovery",
    "employeeNumber": "employee_number",
    "entityKey": "entity_key",
    "entityUrl": "entity_url",
    "expiresAt": "expires_at",
    "expressionType": "expression_type",
    "expressionValue": "expression_value",
    "externalName": "external_name",
    "extraFieldSelector": "extra_field_selector",
    "extraFieldValue": "extra_field_value",
    "fidoU2f": "fido_u2f",
    "fidoWebauthn": "fido_webauthn",
    "firstName": "first_name",
    "googleOtp": "google_otp",
    "grantTypeWhitelists": "grant_type_whitelists",
    "grantTypes": "grant_types",
    "groupAssignments": "group_assignments",
    "groupBlacklists": "group_blacklists",
    "groupFilterType": "group_filter_type",
    "groupId": "group_id",
    "groupMemberships": "group_memberships",
    "groupWhitelists": "group_whitelists",
    "groupsAction": "groups_action",
    "groupsAssignments": "groups_assignments",
    "groupsAttribute": "groups_attribute",
    "groupsFilters": "groups_filters",
    "groupsIncludeds": "groups_includeds",
    "hideIos": "hide_ios",
    "hideWeb": "hide_web",
    "honorForceAuthn": "honor_force_authn",
    "honorificPrefix": "honorific_prefix",
    "honorificSuffix": "honorific_suffix",
    "httpPostBinding": "http_post_binding",
    "httpRedirectBinding": "http_redirect_binding",
    "idpId": "idp_id",
    "idpIssuer": "idp_issuer",
    "idpType": "idp_type",
    "inlineHookId": "inline_hook_id",
    "issuerMode": "issuer_mode",
    "issuerUrl": "issuer_url",
    "jwksBinding": "jwks_binding",
    "jwksUrl": "jwks_url",
    "keyId": "key_id",
    "keyName": "key_name",
    "keyYearsValid": "key_years_valid",
    "lastName": "last_name",
    "loginUri": "login_uri",
    "logoUri": "logo_uri",
    "managerId": "manager_id",
    "matchAttribute": "match_attribute",
    "matchType": "match_type",
    "maxClockSkew": "max_clock_skew",
    "maxLength": "max_length",
    "metadataPublish": "metadata_publish",
    "mfaLifetime": "mfa_lifetime",
    "mfaPrompt": "mfa_prompt",
    "mfaRememberDevice": "mfa_remember_device",
    "mfaRequired": "mfa_required",
    "middleName": "middle_name",
    "minLength": "min_length",
    "mobilePhone": "mobile_phone",
    "nameFormat": "name_format",
    "networkConnection": "network_connection",
    "networkExcludes": "network_excludes",
    "networkIncludes": "network_includes",
    "nickName": "nick_name",
    "oktaCall": "okta_call",
    "oktaOtp": "okta_otp",
    "oktaPassword": "okta_password",
    "oktaPush": "okta_push",
    "oktaQuestion": "okta_question",
    "oktaSms": "okta_sms",
    "omitSecret": "omit_secret",
    "oneOfs": "one_ofs",
    "optionalField1": "optional_field1",
    "optionalField1Value": "optional_field1_value",
    "optionalField2": "optional_field2",
    "optionalField2Value": "optional_field2_value",
    "optionalField3": "optional_field3",
    "optionalField3Value": "optional_field3_value",
    "passwordAutoUnlockMinutes": "password_auto_unlock_minutes",
    "passwordChange": "password_change",
    "passwordDictionaryLookup": "password_dictionary_lookup",
    "passwordExcludeFirstName": "password_exclude_first_name",
    "passwordExcludeLastName": "password_exclude_last_name",
    "passwordExcludeUsername": "password_exclude_username",
    "passwordExpireWarnDays": "password_expire_warn_days",
    "passwordField": "password_field",
    "passwordHistoryCount": "password_history_count",
    "passwordMaxAgeDays": "password_max_age_days",
    "passwordMaxLockoutAttempts": "password_max_lockout_attempts",
    "passwordMinAgeMinutes": "password_min_age_minutes",
    "passwordMinLength": "password_min_length",
    "passwordMinLowercase": "password_min_lowercase",
    "passwordMinNumber": "password_min_number",
    "passwordMinSymbol": "password_min_symbol",
    "passwordMinUppercase": "password_min_uppercase",
    "passwordReset": "password_reset",
    "passwordSelector": "password_selector",
    "passwordShowLockoutFailures": "password_show_lockout_failures",
    "passwordUnlock": "password_unlock",
    "platformIncludes": "platform_includes",
    "policyId": "policy_id",
    "policyUri": "policy_uri",
    "postLogoutRedirectUris": "post_logout_redirect_uris",
    "postalAddress": "postal_address",
    "preconfiguredApp": "preconfigured_app",
    "preferredLanguage": "preferred_language",
    "primaryPhone": "primary_phone",
    "profileMaster": "profile_master",
    "profileUrl": "profile_url",
    "protocolType": "protocol_type",
    "providerId": "provider_id",
    "provisioningAction": "provisioning_action",
    "questionMinLength": "question_min_length",
    "questionRecovery": "question_recovery",
    "rawStatus": "raw_status",
    "recoveryAnswer": "recovery_answer",
    "recoveryEmailToken": "recovery_email_token",
    "recoveryQuestion": "recovery_question",
    "redirectUris": "redirect_uris",
    "refreshTokenLifetimeMinutes": "refresh_token_lifetime_minutes",
    "refreshTokenWindowMinutes": "refresh_token_window_minutes",
    "requestCompressed": "request_compressed",
    "requestIntegration": "request_integration",
    "requestSignatureAlgorithm": "request_signature_algorithm",
    "requestSignatureScope": "request_signature_scope",
    "responseSignatureAlgorithm": "response_signature_algorithm",
    "responseSignatureScope": "response_signature_scope",
    "responseSigned": "response_signed",
    "responseTypes": "response_types",
    "revealPassword": "reveal_password",
    "rsaToken": "rsa_token",
    "scopeWhitelists": "scope_whitelists",
    "secondEmail": "second_email",
    "sessionIdle": "session_idle",
    "sessionLifetime": "session_lifetime",
    "sessionPersistent": "session_persistent",
    "sharedPassword": "shared_password",
    "sharedUsername": "shared_username",
    "signOnMode": "sign_on_mode",
    "signOnRedirectUrl": "sign_on_redirect_url",
    "signOnUrl": "sign_on_url",
    "signatureAlgorithm": "signature_algorithm",
    "skipUnlock": "skip_unlock",
    "smsRecovery": "sms_recovery",
    "sourceId": "source_id",
    "sourceName": "source_name",
    "sourceType": "source_type",
    "spIssuer": "sp_issuer",
    "ssoBinding": "sso_binding",
    "ssoDestination": "sso_destination",
    "ssoUrl": "sso_url",
    "streetAddress": "street_address",
    "subjectFilter": "subject_filter",
    "subjectFormats": "subject_formats",
    "subjectMatchAttribute": "subject_match_attribute",
    "subjectMatchType": "subject_match_type",
    "subjectNameIdFormat": "subject_name_id_format",
    "subjectNameIdTemplate": "subject_name_id_template",
    "suspendedAction": "suspended_action",
    "symantecVip": "symantec_vip",
    "targetId": "target_id",
    "targetName": "target_name",
    "targetType": "target_type",
    "tokenBinding": "token_binding",
    "tokenEndpointAuthMethod": "token_endpoint_auth_method",
    "tokenUrl": "token_url",
    "tosUri": "tos_uri",
    "urlRegex": "url_regex",
    "userBlacklists": "user_blacklists",
    "userId": "user_id",
    "userIdentifierAttribute": "user_identifier_attribute",
    "userIdentifierPatterns": "user_identifier_patterns",
    "userIdentifierType": "user_identifier_type",
    "userInfoBinding": "user_info_binding",
    "userInfoUrl": "user_info_url",
    "userNameTemplate": "user_name_template",
    "userNameTemplateSuffix": "user_name_template_suffix",
    "userNameTemplateType": "user_name_template_type",
    "userType": "user_type",
    "userWhitelists": "user_whitelists",
    "usernameField": "username_field",
    "usernameSelector": "username_selector",
    "usernameTemplate": "username_template",
    "usersExcludeds": "users_excludeds",
    "valueType": "value_type",
    "x5tS256": "x5t_s256",
    "yubikeyToken": "yubikey_token",
    "zipCode": "zip_code",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class PasswordPolicyRule(pulumi.CustomResource):
    name: pulumi.Output[str]
    """
    Policy Rule Name
    """
    network_connection: pulumi.Output[str]
    """
    Network selection mode: ANYWHERE, ZONE, ON_NETWORK, or OFF_NETWORK.
    """
    network_excludes: pulumi.Output[list]
    """
    The zones to exclude
    """
    network_includes: pulumi.Output[list]
    """
    The zones to include
    """
    password_change: pulumi.Output[str]
    """
    Allow or deny a user to change their password: ALLOW or DENY. Default = ALLOW
    """
    password_reset: pulumi.Output[str]
    """
    Allow or deny a user to reset their password: ALLOW or DENY. Default = ALLOW
    """
    password_unlock: pulumi.Output[str]
    """
    Allow or deny a user to unlock. Default = DENY
    """
    policyid: pulumi.Output[str]
    """
    Policy ID of the Rule
    """
    priority: pulumi.Output[float]
    """
    Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an
    invalid priority is provided. API defaults it to the last/lowest if not there.
    """
    status: pulumi.Output[str]
    """
    Policy Rule Status: ACTIVE or INACTIVE.
    """
    users_excludeds: pulumi.Output[list]
    """
    Set of User IDs to Exclude
    """
    def __init__(__self__, resource_name, opts=None, name=None, network_connection=None, network_excludes=None, network_includes=None, password_change=None, password_reset=None, password_unlock=None, policyid=None, priority=None, status=None, users_excludeds=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a PasswordPolicyRule resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Policy Rule Name
        :param pulumi.Input[str] network_connection: Network selection mode: ANYWHERE, ZONE, ON_NETWORK, or OFF_NETWORK.
        :param pulumi.Input[list] network_excludes: The zones to exclude
        :param pulumi.Input[list] network_includes: The zones to include
        :param pulumi.Input[str] password_change: Allow or deny a user to change their password: ALLOW or DENY. Default = ALLOW
        :param pulumi.Input[str] password_reset: Allow or deny a user to reset their password: ALLOW or DENY. Default = ALLOW
        :param pulumi.Input[str] password_unlock: Allow or deny a user to unlock. Default = DENY
        :param pulumi.Input[str] policyid: Policy ID of the Rule
        :param pulumi.Input[float] priority: Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an
               invalid priority is provided. API defaults it to the last/lowest if not there.
        :param pulumi.Input[str] status: Policy Rule Status: ACTIVE or INACTIVE.
        :param pulumi.Input[list] users_excludeds: Set of User IDs to Exclude
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['name'] = name
            __props__['network_connection'] = network_connection
            __props__['network_excludes'] = network_excludes
            __props__['network_includes'] = network_includes
            __props__['password_change'] = password_change
            __props__['password_reset'] = password_reset
            __props__['password_unlock'] = password_unlock
            if policyid is None:
                raise TypeError("Missing required property 'policyid'")
            __props__['policyid'] = policyid
            __props__['priority'] = priority
            __props__['status'] = status
            __props__['users_excludeds'] = users_excludeds
        super(PasswordPolicyRule, __self__).__init__(
            'okta:deprecated/passwordPolicyRule:PasswordPolicyRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, name=None, network_connection=None, network_excludes=None, network_includes=None, password_change=None, password_reset=None, password_unlock=None, policyid=None, priority=None, status=None, users_excludeds=None):
        """
        Get an existing PasswordPolicyRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: Policy Rule Name
        :param pulumi.Input[str] network_connection: Network selection mode: ANYWHERE, ZONE, ON_NETWORK, or OFF_NETWORK.
        :param pulumi.Input[list] network_excludes: The zones to exclude
        :param pulumi.Input[list] network_includes: The zones to include
        :param pulumi.Input[str] password_change: Allow or deny a user to change their password: ALLOW or DENY. Default = ALLOW
        :param pulumi.Input[str] password_reset: Allow or deny a user to reset their password: ALLOW or DENY. Default = ALLOW
        :param pulumi.Input[str] password_unlock: Allow or deny a user to unlock. Default = DENY
        :param pulumi.Input[str] policyid: Policy ID of the Rule
        :param pulumi.Input[float] priority: Policy Rule Priority, this attribute can be set to a valid priority. To avoid endless diff situation we error if an
               invalid priority is provided. API defaults it to the last/lowest if not there.
        :param pulumi.Input[str] status: Policy Rule Status: ACTIVE or INACTIVE.
        :param pulumi.Input[list] users_excludeds: Set of User IDs to Exclude
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["name"] = name
        __props__["network_connection"] = network_connection
        __props__["network_excludes"] = network_excludes
        __props__["network_includes"] = network_includes
        __props__["password_change"] = password_change
        __props__["password_reset"] = password_reset
        __props__["password_unlock"] = password_unlock
        __props__["policyid"] = policyid
        __props__["priority"] = priority
        __props__["status"] = status
        __props__["users_excludeds"] = users_excludeds
        return PasswordPolicyRule(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class Provider(pulumi.ProviderResource):
    def __init__(__self__, resource_name, opts=None, api_token=None, backoff=None, base_url=None, max_retries=None, max_wait_seconds=None, min_wait_seconds=None, org_name=None, parallelism=None, __props__=None, __name__=None, __opts__=None):
        """
        The provider type for the okta package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] api_token: API Token granting privileges to Okta API.
        :param pulumi.Input[bool] backoff: Use exponential back off strategy for rate limits.
        :param pulumi.Input[str] base_url: The Okta url. (Use 'oktapreview.com' for Okta testing)
        :param pulumi.Input[float] max_retries: maximum number of retries to attempt before erroring out.
        :param pulumi.Input[float] max_wait_seconds: maximum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
        :param pulumi.Input[float] min_wait_seconds: minimum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
        :param pulumi.Input[str] org_name: The organization to manage in Okta.
        :param pulumi.Input[float] parallelism: Number of concurrent requests to make within a resource where bulk operations are not possible. Take note of
               https://developer.okta.com/docs/api/getting_started/rate-limits.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if api_token is None:
                api_token = utilities.get_env('OKTA_API_TOKEN')
            __props__['api_token'] = api_token
            __props__['backoff'] = pulumi.Output.from_input(backoff).apply(json.dumps) if backoff is not None else None
            if base_url is None:
                base_url = utilities.get_env('OKTA_BASE_URL')
            __props__['base_url'] = base_url
            __props__['max_retries'] = pulumi.Output.from_input(max_retries).apply(json.dumps) if max_retries is not None else None
            __props__['max_wait_seconds'] = pulumi.Output.from_input(max_wait_seconds).apply(json.dumps) if max_wait_seconds is not None else None
            __props__['min_wait_seconds'] = pulumi.Output.from_input(min_wait_seconds).apply(json.dumps) if min_wait_seconds is not None else None
            if org_name is None:
                org_name = utilities.get_env('OKTA_ORG_NAME')
            __props__['org_name'] = org_name
            __props__['parallelism'] = pulumi.Output.from_input(parallelism).apply(json.dumps) if parallelism is not None else None
        super(Provider, __self__).__init__(
            'okta',
            resource_name,
            __props__,
            opts)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class SamlApp(pulumi.CustomResource):
    accessibility_error_redirect_url: pulumi.Output[str]
    """
    Custom error page URL
    """
    accessibility_login_redirect_url: pulumi.Output[str]
    """
    Custom login page URL
    """
    accessibility_self_service: pulumi.Output[bool]
    """
    Enable self service
    """
    app_settings_json: pulumi.Output[str]
    """
    Application settings in JSON format
    """
    assertion_signed: pulumi.Output[bool]
    """
    Determines whether the SAML assertion is digitally signed
    """
    attribute_statements: pulumi.Output[list]
    audience: pulumi.Output[str]
    """
    Audience Restriction
    """
    authn_context_class_ref: pulumi.Output[str]
    """
    Identifies the SAML authentication context class for the assertion’s authentication statement
    """
    auto_submit_toolbar: pulumi.Output[bool]
    """
    Display auto submit toolbar
    """
    certificate: pulumi.Output[str]
    """
    cert from SAML XML metadata payload
    """
    default_relay_state: pulumi.Output[str]
    """
    Identifies a specific application resource in an IDP initiated SSO scenario.
    """
    destination: pulumi.Output[str]
    """
    Identifies the location where the SAML response is intended to be sent inside of the SAML assertion
    """
    digest_algorithm: pulumi.Output[str]
    """
    Determines the digest algorithm used to digitally sign the SAML assertion and response
    """
    entity_key: pulumi.Output[str]
    """
    Entity ID, the ID portion of the entity_url
    """
    entity_url: pulumi.Output[str]
    """
    Entity URL for instance http://www.okta.com/exk1fcia6d6EMsf331d8
    """
    features: pulumi.Output[list]
    """
    features to enable
    """
    groups: pulumi.Output[list]
    """
    Groups associated with the application
    """
    hide_ios: pulumi.Output[bool]
    """
    Do not display application icon on mobile app
    """
    hide_web: pulumi.Output[bool]
    """
    Do not display application icon to users
    """
    honor_force_authn: pulumi.Output[bool]
    """
    Prompt user to re-authenticate if SP asks for it
    """
    http_post_binding: pulumi.Output[str]
    """
    urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Post location from the SAML metadata.
    """
    http_redirect_binding: pulumi.Output[str]
    """
    urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect location from the SAML metadata.
    """
    idp_issuer: pulumi.Output[str]
    """
    SAML issuer ID
    """
    key_id: pulumi.Output[str]
    """
    Certificate ID
    """
    key_name: pulumi.Output[str]
    """
    Certificate name. This modulates the rotation of keys. New name == new key.
    """
    key_years_valid: pulumi.Output[float]
    """
    Number of years the certificate is valid.
    """
    label: pulumi.Output[str]
    """
    Pretty name of app.
    """
    metadata: pulumi.Output[str]
    """
    SAML xml metadata payload
    """
    name: pulumi.Output[str]
    """
    name of app.
    """
    preconfigured_app: pulumi.Output[str]
    """
    Name of preexisting SAML application. For instance 'slack'
    """
    recipient: pulumi.Output[str]
    """
    The location where the app may present the SAML assertion
    """
    request_compressed: pulumi.Output[bool]
    """
    Denotes whether the request is compressed or not.
    """
    response_signed: pulumi.Output[bool]
    """
    Determines whether the SAML auth response message is digitally signed
    """
    sign_on_mode: pulumi.Output[str]
    """
    Sign on mode of application.
    """
    signature_algorithm: pulumi.Output[str]
    """
    Signature algorithm used ot digitally sign the assertion and response
    """
    sp_issuer: pulumi.Output[str]
    """
    SAML SP issuer ID
    """
    sso_url: pulumi.Output[str]
    """
    Single Sign On URL
    """
    status: pulumi.Output[str]
    """
    Status of application.
    """
    subject_name_id_format: pulumi.Output[str]
    """
    Identifies the SAML processing rules.
    """
    subject_name_id_template: pulumi.Output[str]
    """
    Template for app user's username when a user is assigned to the app
    """
    user_name_template: pulumi.Output[str]
    """
    Username template
    """
    user_name_template_suffix: pulumi.Output[str]
    """
    Username template suffix
    """
    user_name_template_type: pulumi.Output[str]
    """
    Username template type
    """
    users: pulumi.Output[list]
    """
    Users associated with the application

      * `id` (`str`)
      * `password` (`str`)
      * `scope` (`str`)
      * `username` (`str`)
    """
    def __init__(__self__, resource_name, opts=None, accessibility_error_redirect_url=None, accessibility_login_redirect_url=None, accessibility_self_service=None, app_settings_json=None, assertion_signed=None, attribute_statements=None, audience=None, authn_context_class_ref=None, auto_submit_toolbar=None, default_relay_state=None, destination=None, digest_algorithm=None, features=None, groups=None, hide_ios=None, hide_web=None, honor_force_authn=None, idp_issuer=None, key_name=None, key_years_valid=None, label=None, preconfigured_app=None, recipient=None, request_compressed=None, response_signed=None, signature_algorithm=None, sp_issuer=None, sso_url=None, status=None, subject_name_id_format=None, subject_name_id_template=None, user_name_template=None, user_name_template_suffix=None, user_name_template_type=None, users=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a SamlApp resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[bool] accessibility_self_service: Enable self service
        :param pulumi.Input[str] app_settings_json: Application settings in JSON format
        :param pulumi.Input[bool] assertion_signed: Determines whether the SAML assertion is digitally signed
        :param pulumi.Input[str] audience: Audience Restriction
        :param pulumi.Input[str] authn_context_class_ref: Identifies the SAML authentication context class for the assertion’s authentication statement
        :param pulumi.Input[bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[str] default_relay_state: Identifies a specific application resource in an IDP initiated SSO scenario.
        :param pulumi.Input[str] destination: Identifies the location where the SAML response is intended to be sent inside of the SAML assertion
        :param pulumi.Input[str] digest_algorithm: Determines the digest algorithm used to digitally sign the SAML assertion and response
        :param pulumi.Input[list] features: features to enable
        :param pulumi.Input[list] groups: Groups associated with the application
        :param pulumi.Input[bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[bool] hide_web: Do not display application icon to users
        :param pulumi.Input[bool] honor_force_authn: Prompt user to re-authenticate if SP asks for it
        :param pulumi.Input[str] idp_issuer: SAML issuer ID
        :param pulumi.Input[str] key_name: Certificate name. This modulates the rotation of keys. New name == new key.
        :param pulumi.Input[float] key_years_valid: Number of years the certificate is valid.
        :param pulumi.Input[str] label: Pretty name of app.
        :param pulumi.Input[str] preconfigured_app: Name of preexisting SAML application. For instance 'slack'
        :param pulumi.Input[str] recipient: The location where the app may present the SAML assertion
        :param pulumi.Input[bool] request_compressed: Denotes whether the request is compressed or not.
        :param pulumi.Input[bool] response_signed: Determines whether the SAML auth response message is digitally signed
        :param pulumi.Input[str] signature_algorithm: Signature algorithm used ot digitally sign the assertion and response
        :param pulumi.Input[str] sp_issuer: SAML SP issuer ID
        :param pulumi.Input[str] sso_url: Single Sign On URL
        :param pulumi.Input[str] status: Status of application.
        :param pulumi.Input[str] subject_name_id_format: Identifies the SAML processing rules.
        :param pulumi.Input[str] subject_name_id_template: Template for app user's username when a user is assigned to the app
        :param pulumi.Input[str] user_name_template: Username template
        :param pulumi.Input[str] user_name_template_suffix: Username template suffix
        :param pulumi.Input[str] user_name_template_type: Username template type
        :param pulumi.Input[list] users: Users associated with the application

        The **attribute_statements** object supports the following:

          * `filterType` (`pulumi.Input[str]`)
          * `filterValue` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)
          * `values` (`pulumi.Input[list]`)

        The **users** object supports the following:

          * `id` (`pulumi.Input[str]`)
          * `password` (`pulumi.Input[str]`)
          * `scope` (`pulumi.Input[str]`)
          * `username` (`pulumi.Input[str]`)
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['accessibility_error_redirect_url'] = accessibility_error_redirect_url
            __props__['accessibility_login_redirect_url'] = accessibility_login_redirect_url
            __props__['accessibility_self_service'] = accessibility_self_service
            __props__['app_settings_json'] = app_settings_json
            __props__['assertion_signed'] = assertion_signed
            __props__['attribute_statements'] = attribute_statements
            __props__['audience'] = audience
            __props__['authn_context_class_ref'] = authn_context_class_ref
            __props__['auto_submit_toolbar'] = auto_submit_toolbar
            __props__['default_relay_state'] = default_relay_state
            __props__['destination'] = destination
            __props__['digest_algorithm'] = digest_algorithm
            __props__['features'] = features
            __props__['groups'] = groups
            __props__['hide_ios'] = hide_ios
            __props__['hide_web'] = hide_web
            __props__['honor_force_authn'] = honor_force_authn
            __props__['idp_issuer'] = idp_issuer
            __props__['key_name'] = key_name
            __props__['key_years_valid'] = key_years_valid
            if label is None:
                raise TypeError("Missing required property 'label'")
            __props__['label'] = label
            __props__['preconfigured_app'] = preconfigured_app
            __props__['recipient'] = recipient
            __props__['request_compressed'] = request_compressed
            __props__['response_signed'] = response_signed
            __props__['signature_algorithm'] = signature_algorithm
            __props__['sp_issuer'] = sp_issuer
            __props__['sso_url'] = sso_url
            __props__['status'] = status
            __props__['subject_name_id_format'] = subject_name_id_format
            __props__['subject_name_id_template'] = subject_name_id_template
            __props__['user_name_template'] = user_name_template
            __props__['user_name_template_suffix'] = user_name_template_suffix
            __props__['user_name_template_type'] = user_name_template_type
            __props__['users'] = users
            __props__['certificate'] = None
            __props__['entity_key'] = None
            __props__['entity_url'] = None
            __props__['http_post_binding'] = None
            __props__['http_redirect_binding'] = None
            __props__['key_id'] = None
            __props__['metadata'] = None
            __props__['name'] = None
            __props__['sign_on_mode'] = None
        super(SamlApp, __self__).__init__(
            'okta:deprecated/samlApp:SamlApp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, accessibility_error_redirect_url=None, accessibility_login_redirect_url=None, accessibility_self_service=None, app_settings_json=None, assertion_signed=None, attribute_statements=None, audience=None, authn_context_class_ref=None, auto_submit_toolbar=None, certificate=None, default_relay_state=None, destination=None, digest_algorithm=None, entity_key=None, entity_url=None, features=None, groups=None, hide_ios=None, hide_web=None, honor_force_authn=None, http_post_binding=None, http_redirect_binding=None, idp_issuer=None, key_id=None, key_name=None, key_years_valid=None, label=None, metadata=None, name=None, preconfigured_app=None, recipient=None, request_compressed=None, response_signed=None, sign_on_mode=None, signature_algorithm=None, sp_issuer=None, sso_url=None, status=None, subject_name_id_format=None, subject_name_id_template=None, user_name_template=None, user_name_template_suffix=None, user_name_template_type=None, users=None):
        """
        Get an existing SamlApp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] accessibility_error_redirect_url: Custom error page URL
        :param pulumi.Input[str] accessibility_login_redirect_url: Custom login page URL
        :param pulumi.Input[bool] accessibility_self_service: Enable self service
        :param pulumi.Input[str] app_settings_json: Application settings in JSON format
        :param pulumi.Input[bool] assertion_signed: Determines whether the SAML assertion is digitally signed
        :param pulumi.Input[str] audience: Audience Restriction
        :param pulumi.Input[str] authn_context_class_ref: Identifies the SAML authentication context class for the assertion’s authentication statement
        :param pulumi.Input[bool] auto_submit_toolbar: Display auto submit toolbar
        :param pulumi.Input[str] certificate: cert from SAML XML metadata payload
        :param pulumi.Input[str] default_relay_state: Identifies a specific application resource in an IDP initiated SSO scenario.
        :param pulumi.Input[str] destination: Identifies the location where the SAML response is intended to be sent inside of the SAML assertion
        :param pulumi.Input[str] digest_algorithm: Determines the digest algorithm used to digitally sign the SAML assertion and response
        :param pulumi.Input[str] entity_key: Entity ID, the ID portion of the entity_url
        :param pulumi.Input[str] entity_url: Entity URL for instance http://www.okta.com/exk1fcia6d6EMsf331d8
        :param pulumi.Input[list] features: features to enable
        :param pulumi.Input[list] groups: Groups associated with the application
        :param pulumi.Input[bool] hide_ios: Do not display application icon on mobile app
        :param pulumi.Input[bool] hide_web: Do not display application icon to users
        :param pulumi.Input[bool] honor_force_authn: Prompt user to re-authenticate if SP asks for it
        :param pulumi.Input[str] http_post_binding: urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Post location from the SAML metadata.
        :param pulumi.Input[str] http_redirect_binding: urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect location from the SAML metadata.
        :param pulumi.Input[str] idp_issuer: SAML issuer ID
        :param pulumi.Input[str] key_id: Certificate ID
        :param pulumi.Input[str] key_name: Certificate name. This modulates the rotation of keys. New name == new key.
        :param pulumi.Input[float] key_years_valid: Number of years the certificate is valid.
        :param pulumi.Input[str] label: Pretty name of app.
        :param pulumi.Input[str] metadata: SAML xml metadata payload
        :param pulumi.Input[str] name: name of app.
        :param pulumi.Input[str] preconfigured_app: Name of preexisting SAML application. For instance 'slack'
        :param pulumi.Input[str] recipient: The location where the app may present the SAML assertion
        :param pulumi.Input[bool] request_compressed: Denotes whether the request is compressed or not.
        :param pulumi.Input[bool] response_signed: Determines whether the SAML auth response message is digitally signed
        :param pulumi.Input[str] sign_on_mode: Sign on mode of application.
        :param pulumi.Input[str] signature_algorithm: Signature algorithm used ot digitally sign the assertion and response
        :param pulumi.Input[str] sp_issuer: SAML SP issuer ID
        :param pulumi.Input[str] sso_url: Single Sign On URL
        :param pulumi.Input[str] status: Status of application.
        :param pulumi.Input[str] subject_name_id_format: Identifies the SAML processing rules.
        :param pulumi.Input[str] subject_name_id_template: Template for app user's username when a user is assigned to the app
        :param pulumi.Input[str] user_name_template: Username template
        :param pulumi.Input[str] user_name_template_suffix: Username template suffix
        :param pulumi.Input[str] user_name_template_type: Username template type
        :param pulumi.Input[list] users: Users associated with the application

        The **attribute_statements** object supports the following:

          * `filterType` (`pulumi.Input[str]`)
          * `filterValue` (`pulumi.Input[str]`)
          * `name` (`pulumi.Input[str]`)
          * `namespace` (`pulumi.Input[str]`)
          * `type` (`pulumi.Input[str]`)
          * `values` (`pulumi.Input[list]`)

        The **users** object supports the following:

          * `id` (`pulumi.Input[str]`)
          * `password` (`pulumi.Input[str]`)
          * `scope` (`pulumi.Input[str]`)
          * `username` (`pulumi.Input[str]`)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["accessibility_error_redirect_url"] = accessibility_error_redirect_url
        __props__["accessibility_login_redirect_url"] = accessibility_login_redirect_url
        __props__["accessibility_self_service"] = accessibility_self_service
        __props__["app_settings_json"] = app_settings_json
        __props__["assertion_signed"] = assertion_signed
        __props__["attribute_statements"] = attribute_statements
        __props__["audience"] = audience
        __props__["authn_context_class_ref"] = authn_context_class_ref
        __props__["auto_submit_toolbar"] = auto_submit_toolbar
        __props__["certificate"] = certificate
        __props__["default_relay_state"] = default_relay_state
        __props__["destination"] = destination
        __props__["digest_algorithm"] = digest_algorithm
        __props__["entity_key"] = entity_key
        __props__["entity_url"] = entity_url
        __props__["features"] = features
        __props__["groups"] = groups
        __props__["hide_ios"] = hide_ios
        __props__["hide_web"] = hide_web
        __props__["honor_force_authn"] = honor_force_authn
        __props__["http_post_binding"] = http_post_binding
        __props__["http_redirect_binding"] = http_redirect_binding
        __props__["idp_issuer"] = idp_issuer
        __props__["key_id"] = key_id
        __props__["key_name"] = key_name
        __props__["key_years_valid"] = key_years_valid
        __props__["label"] = label
        __props__["metadata"] = metadata
        __props__["name"] = name
        __props__["preconfigured_app"] = preconfigured_app
        __props__["recipient"] = recipient
        __props__["request_compressed"] = request_compressed
        __props__["response_signed"] = response_signed
        __props__["sign_on_mode"] = sign_on_mode
        __props__["signature_algorithm"] = signature_algorithm
        __props__["sp_issuer"] = sp_issuer
        __props__["sso_url"] = sso_url
        __props__["status"] = status
        __props__["subject_name_id_format"] = subject_name_id_format
        __props__["subject_name_id_template"] = subject_name_id_template
        __props__["user_name_template"] = user_name_template
        __props__["user_name_template_suffix"] = user_name_template_suffix
        __props__["user_name_template_type"] = user_name_template_type
        __props__["users"] = users
        return SamlApp(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('okta')

api_token = __config__.get('apiToken') or utilities.get_env('OKTA_API_TOKEN')
"""
API Token granting privileges to Okta API.
"""

backoff = __config__.get('backoff')
"""
Use exponential back off strategy for rate limits.
"""

base_url = __config__.get('baseUrl') or utilities.get_env('OKTA_BASE_URL')
"""
The Okta url. (Use 'oktapreview.com' for Okta testing)
"""

max_retries = __config__.get('maxRetries')
"""
maximum number of retries to attempt before erroring out.
"""

max_wait_seconds = __config__.get('maxWaitSeconds')
"""
maximum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
"""

min_wait_seconds = __config__.get('minWaitSeconds')
"""
minimum seconds to wait when rate limit is hit. We use exponential backoffs when backoff is enabled.
"""

org_name = __config__.get('orgName') or utilities.get_env('OKTA_ORG_NAME')
"""
The organization to manage in Okta.
"""

parallelism = __config__.get('parallelism')
"""
Number of concurrent requests to make within a resource where bulk operations are not possible. Take note of
https://developer.okta.com/docs/api/getting_started/rate-limits.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class Schema(pulumi.CustomResource):
    array_enums: pulumi.Output[list]
    """
    Array of values that an array property's items can be set to.
    """
    array_one_ofs: pulumi.Output[list]
    """
    Display name and value an enum array can be set to.

      * `const` (`str`) - value mapping to member of `enum`.
      * `title` (`str`) - display name for the enum value.
    """
    array_type: pulumi.Output[str]
    """
    The type of the array elements if `type` is set to `"array"`.
    """
    description: pulumi.Output[str]
    """
    The description of the user schema property.
    """
    enums: pulumi.Output[list]
    """
    Array of values a primitive property can be set to. See `array_enum` for arrays.
    """
    external_name: pulumi.Output[str]
    """
    External name of the user schema property.
    """
    index: pulumi.Output[str]
    """
    The property name.
    """
    master: pulumi.Output[str]
    """
    Master priority for the user schema property. It can be set to `"PROFILE_MASTER"` or `"OKTA"`.
    """
    max_length: pulumi.Output[float]
    """
    The maximum length of the user property value. Only applies to type `"string"`.
    """
    min_length: pulumi.Output[float]
    """
    The minimum length of the user property value. Only applies to type `"string"`.
    """
    one_ofs: pulumi.Output[list]
    """
    Array of maps containing a mapping for display name to enum value.

      * `const` (`str`) - value mapping to member of `enum`.
      * `title` (`str`) - display name for the enum value.
    """
    permissions: pulumi.Output[str]
    """
    Access control permissions for the property. It can be set to `"READ_WRITE"`, `"READ_ONLY"`, `"HIDE"`.
    """
    required: pulumi.Output[bool]
    """
    Whether the property is required for this application's users.
    """
    scope: pulumi.Output[str]
    """
    determines whether an app user attribute can be set at the Individual or Group Level.
    """
    title: pulumi.Output[str]
    """
    display name for the enum value.
    """
    type: pulumi.Output[str]
    """
    The type of the schema property. It can be `"string"`, `"boolean"`, `"number"`, `"integer"`, `"array"`, or `"object"`.
    """
    def __init__(__self__, resource_name, opts=None, array_enums=None, array_one_ofs=None, array_type=None, description=None, enums=None, external_name=None, index=None, master=None, max_length=None, min_length=None, one_ofs=None, permissions=None, required=None, scope=None, title=None, type=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates a User Schema property.

        This resource allows you to create and configure a custom user schema property.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.user.Schema("example",
            description="My custom property name",
            index="customPropertyName",
            master="OKTA",
            scope="SELF",
            title="customPropertyName",
            type="string")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] array_enums: Array of values that an array property's items can be set to.
        :param pulumi.Input[list] array_one_ofs: Display name and value an enum array can be set to.
        :param pulumi.Input[str] array_type: The type of the array elements if `type` is set to `"array"`.
        :param pulumi.Input[str] description: The description of the user schema property.
        :param pulumi.Input[list] enums: Array of values a primitive property can be set to. See `array_enum` for arrays.
        :param pulumi.Input[str] external_name: External name of the user schema property.
        :param pulumi.Input[str] index: The property name.
        :param pulumi.Input[str] master: Master priority for the user schema property. It can be set to `"PROFILE_MASTER"` or `"OKTA"`.
        :param pulumi.Input[float] max_length: The maximum length of the user property value. Only applies to type `"string"`.
        :param pulumi.Input[float] min_length: The minimum length of the user property value. Only applies to type `"string"`.
        :param pulumi.Input[list] one_ofs: Array of maps containing a mapping for display name to enum value.
        :param pulumi.Input[str] permissions: Access control permissions for the property. It can be set to `"READ_WRITE"`, `"READ_ONLY"`, `"HIDE"`.
        :param pulumi.Input[bool] required: Whether the property is required for this application's users.
        :param pulumi.Input[str] scope: determines whether an app user attribute can be set at the Individual or Group Level.
        :param pulumi.Input[str] title: display name for the enum value.
        :param pulumi.Input[str] type: The type of the schema property. It can be `"string"`, `"boolean"`, `"number"`, `"integer"`, `"array"`, or `"object"`.

        The **array_one_ofs** object supports the following:

          * `const` (`pulumi.Input[str]`) - value mapping to member of `enum`.
          * `title` (`pulumi.Input[str]`) - display name for the enum value.

        The **one_ofs** object supports the following:

          * `const` (`pulumi.Input[str]`) - value mapping to member of `enum`.
          * `title` (`pulumi.Input[str]`) - display name for the enum value.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['array_enums'] = array_enums
            __props__['array_one_ofs'] = array_one_ofs
            __props__['array_type'] = array_type
            __props__['description'] = description
            __props__['enums'] = enums
            __props__['external_name'] = external_name
            if index is None:
                raise TypeError("Missing required property 'index'")
            __props__['index'] = index
            __props__['master'] = master
            __props__['max_length'] = max_length
            __props__['min_length'] = min_length
            __props__['one_ofs'] = one_ofs
            __props__['permissions'] = permissions
            __props__['required'] = required
            __props__['scope'] = scope
            if title is None:
                raise TypeError("Missing required property 'title'")
            __props__['title'] = title
            if type is None:
                raise TypeError("Missing required property 'type'")
            __props__['type'] = type
        super(Schema, __self__).__init__(
            'okta:user/schema:Schema',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, array_enums=None, array_one_ofs=None, array_type=None, description=None, enums=None, external_name=None, index=None, master=None, max_length=None, min_length=None, one_ofs=None, permissions=None, required=None, scope=None, title=None, type=None):
        """
        Get an existing Schema resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] array_enums: Array of values that an array property's items can be set to.
        :param pulumi.Input[list] array_one_ofs: Display name and value an enum array can be set to.
        :param pulumi.Input[str] array_type: The type of the array elements if `type` is set to `"array"`.
        :param pulumi.Input[str] description: The description of the user schema property.
        :param pulumi.Input[list] enums: Array of values a primitive property can be set to. See `array_enum` for arrays.
        :param pulumi.Input[str] external_name: External name of the user schema property.
        :param pulumi.Input[str] index: The property name.
        :param pulumi.Input[str] master: Master priority for the user schema property. It can be set to `"PROFILE_MASTER"` or `"OKTA"`.
        :param pulumi.Input[float] max_length: The maximum length of the user property value. Only applies to type `"string"`.
        :param pulumi.Input[float] min_length: The minimum length of the user property value. Only applies to type `"string"`.
        :param pulumi.Input[list] one_ofs: Array of maps containing a mapping for display name to enum value.
        :param pulumi.Input[str] permissions: Access control permissions for the property. It can be set to `"READ_WRITE"`, `"READ_ONLY"`, `"HIDE"`.
        :param pulumi.Input[bool] required: Whether the property is required for this application's users.
        :param pulumi.Input[str] scope: determines whether an app user attribute can be set at the Individual or Group Level.
        :param pulumi.Input[str] title: display name for the enum value.
        :param pulumi.Input[str] type: The type of the schema property. It can be `"string"`, `"boolean"`, `"number"`, `"integer"`, `"array"`, or `"object"`.

        The **array_one_ofs** object supports the following:

          * `const` (`pulumi.Input[str]`) - value mapping to member of `enum`.
          * `title` (`pulumi.Input[str]`) - display name for the enum value.

        The **one_ofs** object supports the following:

          * `const` (`pulumi.Input[str]`) - value mapping to member of `enum`.
          * `title` (`pulumi.Input[str]`) - display name for the enum value.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["array_enums"] = array_enums
        __props__["array_one_ofs"] = array_one_ofs
        __props__["array_type"] = array_type
        __props__["description"] = description
        __props__["enums"] = enums
        __props__["external_name"] = external_name
        __props__["index"] = index
        __props__["master"] = master
        __props__["max_length"] = max_length
        __props__["min_length"] = min_length
        __props__["one_ofs"] = one_ofs
        __props__["permissions"] = permissions
        __props__["required"] = required
        __props__["scope"] = scope
        __props__["title"] = title
        __props__["type"] = type
        return Schema(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class ServerScope(pulumi.CustomResource):
    auth_server_id: pulumi.Output[str]
    """
    Auth Server ID.
    """
    consent: pulumi.Output[str]
    """
    Indicates whether a consent dialog is needed for the scope. It can be set to `"REQUIRED"` or `"IMPLICIT"`.
    """
    default: pulumi.Output[bool]
    """
    A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
    """
    description: pulumi.Output[str]
    """
    Description of the Auth Server Scope.
    """
    metadata_publish: pulumi.Output[str]
    """
    Whether to publish metadata or not. It can be set to `"ALL_CLIENTS"` or `"NO_CLIENTS"`.
    """
    name: pulumi.Output[str]
    """
    Auth Server scope name.
    """
    def __init__(__self__, resource_name, opts=None, auth_server_id=None, consent=None, default=None, description=None, metadata_publish=None, name=None, __props__=None, __name__=None, __opts__=None):
        """
        Creates an Authorization Server Scope.

        This resource allows you to create and configure an Authorization Server Scope.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.auth.ServerScope("example",
            auth_server_id="<auth server id>",
            consent="IMPLICIT",
            metadata_publish="NO_CLIENTS")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_server_id: Auth Server ID.
        :param pulumi.Input[str] consent: Indicates whether a consent dialog is needed for the scope. It can be set to `"REQUIRED"` or `"IMPLICIT"`.
        :param pulumi.Input[bool] default: A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        :param pulumi.Input[str] description: Description of the Auth Server Scope.
        :param pulumi.Input[str] metadata_publish: Whether to publish metadata or not. It can be set to `"ALL_CLIENTS"` or `"NO_CLIENTS"`.
        :param pulumi.Input[str] name: Auth Server scope name.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if auth_server_id is None:
                raise TypeError("Missing required property 'auth_server_id'")
            __props__['auth_server_id'] = auth_server_id
            __props__['consent'] = consent
            __props__['default'] = default
            __props__['description'] = description
            __props__['metadata_publish'] = metadata_publish
            __props__['name'] = name
        super(ServerScope, __self__).__init__(
            'okta:auth/serverScope:ServerScope',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, auth_server_id=None, consent=None, default=None, description=None, metadata_publish=None, name=None):
        """
        Get an existing ServerScope resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] auth_server_id: Auth Server ID.
        :param pulumi.Input[str] consent: Indicates whether a consent dialog is needed for the scope. It can be set to `"REQUIRED"` or `"IMPLICIT"`.
        :param pulumi.Input[bool] default: A default scope will be returned in an access token when the client omits the scope parameter in a token request, provided this scope is allowed as part of the access policy rule.
        :param pulumi.Input[str] description: Description of the Auth Server Scope.
        :param pulumi.Input[str] metadata_publish: Whether to publish metadata or not. It can be set to `"ALL_CLIENTS"` or `"NO_CLIENTS"`.
        :param pulumi.Input[str] name: Auth Server scope name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["auth_server_id"] = auth_server_id
        __props__["consent"] = consent
        __props__["default"] = default
        __props__["description"] = description
        __props__["metadata_publish"] = metadata_publish
        __props__["name"] = name
        return ServerScope(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

class GetMetadataSamlResult:
    """
    A collection of values returned by getMetadataSaml.
    """
    def __init__(__self__, assertions_signed=None, authn_request_signed=None, encryption_certificate=None, entity_id=None, http_post_binding=None, http_redirect_binding=None, id=None, idp_id=None, metadata=None, signing_certificate=None):
        if assertions_signed and not isinstance(assertions_signed, bool):
            raise TypeError("Expected argument 'assertions_signed' to be a bool")
        __self__.assertions_signed = assertions_signed
        """
        whether assertions are signed.
        """
        if authn_request_signed and not isinstance(authn_request_signed, bool):
            raise TypeError("Expected argument 'authn_request_signed' to be a bool")
        __self__.authn_request_signed = authn_request_signed
        """
        whether authn requests are signed.
        """
        if encryption_certificate and not isinstance(encryption_certificate, str):
            raise TypeError("Expected argument 'encryption_certificate' to be a str")
        __self__.encryption_certificate = encryption_certificate
        """
        SAML request encryption certificate.
        """
        if entity_id and not isinstance(entity_id, str):
            raise TypeError("Expected argument 'entity_id' to be a str")
        __self__.entity_id = entity_id
        """
        Entity URL for instance `https://www.okta.com/saml2/service-provider/sposcfdmlybtwkdcgtuf`.
        """
        if http_post_binding and not isinstance(http_post_binding, str):
            raise TypeError("Expected argument 'http_post_binding' to be a str")
        __self__.http_post_binding = http_post_binding
        """
        urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Post location from the SAML metadata.
        """
        if http_redirect_binding and not isinstance(http_redirect_binding, str):
            raise TypeError("Expected argument 'http_redirect_binding' to be a str")
        __self__.http_redirect_binding = http_redirect_binding
        """
        urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect location from the SAML metadata.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if idp_id and not isinstance(idp_id, str):
            raise TypeError("Expected argument 'idp_id' to be a str")
        __self__.idp_id = idp_id
        if metadata and not isinstance(metadata, str):
            raise TypeError("Expected argument 'metadata' to be a str")
        __self__.metadata = metadata
        """
        raw IdP metadata.
        """
        if signing_certificate and not isinstance(signing_certificate, str):
            raise TypeError("Expected argument 'signing_certificate' to be a str")
        __self__.signing_certificate = signing_certificate
        """
        SAML request signing certificate.
        """
class AwaitableGetMetadataSamlResult(GetMetadataSamlResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMetadataSamlResult(
            assertions_signed=self.assertions_signed,
            authn_request_signed=self.authn_request_signed,
            encryption_certificate=self.encryption_certificate,
            entity_id=self.entity_id,
            http_post_binding=self.http_post_binding,
            http_redirect_binding=self.http_redirect_binding,
            id=self.id,
            idp_id=self.idp_id,
            metadata=self.metadata,
            signing_certificate=self.signing_certificate)

def get_metadata_saml(idp_id=None,opts=None):
    """
    Use this data source to retrieve SAML IdP metadata from Okta.

    ## Example Usage



    ```python
    import pulumi
    import pulumi_okta as okta

    example = okta.idp.get_metadata_saml(id="<idp id>")
    ```



    :param str idp_id: The id of the IdP to retrieve metadata for.
    """
    __args__ = dict()


    __args__['idpId'] = idp_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('okta:idp/getMetadataSaml:getMetadataSaml', __args__, opts=opts).value

    return AwaitableGetMetadataSamlResult(
        assertions_signed=__ret__.get('assertionsSigned'),
        authn_request_signed=__ret__.get('authnRequestSigned'),
        encryption_certificate=__ret__.get('encryptionCertificate'),
        entity_id=__ret__.get('entityId'),
        http_post_binding=__ret__.get('httpPostBinding'),
        http_redirect_binding=__ret__.get('httpRedirectBinding'),
        id=__ret__.get('id'),
        idp_id=__ret__.get('idpId'),
        metadata=__ret__.get('metadata'),
        signing_certificate=__ret__.get('signingCertificate'))
